@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 sub new {
     my ($class, %args) = @_;
@@ -18,7 +18,7 @@ sub Load {
     require YAML::PP::Loader;
     my ($self, $yaml) = @_;
     $self->{loader} = YAML::PP::Loader->new;
-    return $self->loader->Load($yaml);
+    return $self->loader->load($yaml);
 }
 
 1;
@@ -44,8 +44,8 @@ Here are a few examples of what you can do right now:
 
     # The loader offers JSON::PP, boolean.pm or pureperl 1/0 (default)
     # for booleans
-    my $ypp = YAML::PP::Loader->new(boolean => 'JSON::PP');
-    my ($data1, $data2) = $ypp->Load($yaml);
+    my $yppl = YAML::PP::Loader->new(boolean => 'JSON::PP');
+    my ($data1, $data2) = $yppl->load($yaml);
 
     # Print the events from the parser in yaml-test-suite format
     yaml-pp-p5-events < file.yaml
@@ -150,7 +150,7 @@ Example:
             : 23
         : 42
     EOM
-    my $data = $yppl->Load($yaml);
+    my $data = $yppl->load($yaml);
     say $coder->encode($data);
     __END__
     {
@@ -176,7 +176,6 @@ wish to be able to keep the comments.
 
 Compare the output of the following YAML Loaders and JSON::XS dump:
 
-
     use JSON::XS;
     use Devel::Peek;
 
@@ -193,8 +192,8 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     my $d1 = YAML::XS::Load($yaml);
     my $d2 = YAML::Load($yaml);
     my $d3 = YAML::Syck::Load($yaml);
-    my $d4 = YAML::Tiny->read_string($yaml);
-    my $d5 = YAML::PP::Loader->new->Load($yaml);
+    my $d4 = YAML::Tiny->read_string($yaml)->[0];
+    my $d5 = YAML::PP::Loader->new->load($yaml);
 
     Dump $d1->{foo};
     Dump $d2->{foo};
@@ -208,36 +207,32 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     say encode_json($d4);
     say encode_json($d5);
 
-    SV = PVIV(0x564f09465c00) at 0x564f09460780
+    SV = PVIV(0x55bbaff2bae0) at 0x55bbaff26518
       REFCNT = 1
       FLAGS = (IOK,POK,pIOK,pPOK)
       IV = 23
-      PV = 0x564f0945a600 "23"\0
+      PV = 0x55bbb06e67a0 "23"\0
       CUR = 2
       LEN = 10
-
-    SV = PVMG(0x5654d491dd80) at 0x5654d4aca4c8
+    SV = PVMG(0x55bbb08959b0) at 0x55bbb08fc6e8
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
       NV = 0
       PV = 0
-
-    SV = IV(0x564f6fab37d0) at 0x564f6fab37e0
+    SV = IV(0x55bbaffcb3b0) at 0x55bbaffcb3c0
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
-
-    SV = PVMG(0x5640b45a42a0) at 0x5640b4594250
+    SV = PVMG(0x55bbaff2f1f0) at 0x55bbb08fc8c8
       REFCNT = 1
       FLAGS = (POK,pPOK,UTF8)
       IV = 0
       NV = 0
-      PV = 0x5640b45a21f0 "23"\0 [UTF8 "23"]
+      PV = 0x55bbb0909d00 "23"\0 [UTF8 "23"]
       CUR = 2
       LEN = 10
-
-    SV = PVMG(0x564f09b5cbc0) at 0x564f09d473c0
+    SV = PVMG(0x55bbaff2f6d0) at 0x55bbb08b2c10
       REFCNT = 1
       FLAGS = (IOK,pIOK)
       IV = 23
@@ -247,8 +242,9 @@ Compare the output of the following YAML Loaders and JSON::XS dump:
     {"foo":"23"}
     {"foo":23}
     {"foo":23}
-    {"foo":23}
     {"foo":"23"}
+    {"foo":23}
+
 
 
 =head1 WHY
